==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/FailoverGroupReadWriteEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.ReadWriteEndpointFailoverPolicy
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Read-write endpoint of the failover group instance.
 * @property failoverPolicy Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
 * @property failoverWithDataLossGracePeriodMinutes Grace period before failover with data loss is attempted for the read-write endpoint. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
 */
public data class FailoverGroupReadWriteEndpointArgs(
    public val failoverPolicy: Output<Either<String, ReadWriteEndpointFailoverPolicy>>,
    public val failoverWithDataLossGracePeriodMinutes: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs =
        com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs.builder()
            .failoverPolicy(
                failoverPolicy.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .failoverWithDataLossGracePeriodMinutes(
                failoverWithDataLossGracePeriodMinutes?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [FailoverGroupReadWriteEndpointArgs].
 */
@PulumiTagMarker
public class FailoverGroupReadWriteEndpointArgsBuilder internal constructor() {
    private var failoverPolicy: Output<Either<String, ReadWriteEndpointFailoverPolicy>>? = null

    private var failoverWithDataLossGracePeriodMinutes: Output<Int>? = null

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("qcndkeqvshyogjtm")
    public suspend
    fun failoverPolicy(`value`: Output<Either<String, ReadWriteEndpointFailoverPolicy>>) {
        this.failoverPolicy = value
    }

    /**
     * @param value Grace period before failover with data loss is attempted for the read-write endpoint. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("xqukmlyqvjpxukbx")
    public suspend fun failoverWithDataLossGracePeriodMinutes(`value`: Output<Int>) {
        this.failoverWithDataLossGracePeriodMinutes = value
    }

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("nogowbuqyboraecn")
    public suspend fun failoverPolicy(`value`: Either<String, ReadWriteEndpointFailoverPolicy>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failoverPolicy = mapped
    }

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("iypesmlodicitixh")
    public fun failoverPolicy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReadWriteEndpointFailoverPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failoverPolicy = mapped
    }

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("ndmcbfgtxcathhlo")
    public fun failoverPolicy(`value`: ReadWriteEndpointFailoverPolicy) {
        val toBeMapped = Either.ofRight<String, ReadWriteEndpointFailoverPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failoverPolicy = mapped
    }

    /**
     * @param value Grace period before failover with data loss is attempted for the read-write endpoint. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("ycuxeayelnujbsdh")
    public suspend fun failoverWithDataLossGracePeriodMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failoverWithDataLossGracePeriodMinutes = mapped
    }

    internal fun build(): FailoverGroupReadWriteEndpointArgs = FailoverGroupReadWriteEndpointArgs(
        failoverPolicy = failoverPolicy ?: throw PulumiNullFieldException("failoverPolicy"),
        failoverWithDataLossGracePeriodMinutes = failoverWithDataLossGracePeriodMinutes,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/FailoverGroupReadWriteEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs.builder
import com.pulumi.azurenative.sql.kotlin.enums.ReadWriteEndpointFailoverPolicy
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Read-write endpoint of the failover group instance.
 * @property failoverPolicy Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
 * @property failoverWithDataLossGracePeriodMinutes Grace period before failover with data loss is attempted for the read-write endpoint. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
 */
public data class FailoverGroupReadWriteEndpointArgs(
    public val failoverPolicy: Output<Either<String, ReadWriteEndpointFailoverPolicy>>,
    public val failoverWithDataLossGracePeriodMinutes: Output<Int>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs =
        com.pulumi.azurenative.sql.inputs.FailoverGroupReadWriteEndpointArgs.builder()
            .failoverPolicy(
                failoverPolicy.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .failoverWithDataLossGracePeriodMinutes(
                failoverWithDataLossGracePeriodMinutes?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [FailoverGroupReadWriteEndpointArgs].
 */
@PulumiTagMarker
public class FailoverGroupReadWriteEndpointArgsBuilder internal constructor() {
    private var failoverPolicy: Output<Either<String, ReadWriteEndpointFailoverPolicy>>? = null

    private var failoverWithDataLossGracePeriodMinutes: Output<Int>? = null

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("vejhdrhqesgtcmyi")
    public suspend
    fun failoverPolicy(`value`: Output<Either<String, ReadWriteEndpointFailoverPolicy>>) {
        this.failoverPolicy = value
    }

    /**
     * @param value Grace period before failover with data loss is attempted for the read-write endpoint. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("cxqljloruksnuphb")
    public suspend fun failoverWithDataLossGracePeriodMinutes(`value`: Output<Int>) {
        this.failoverWithDataLossGracePeriodMinutes = value
    }

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("nvrfrliuiyjcxnja")
    public suspend fun failoverPolicy(`value`: Either<String, ReadWriteEndpointFailoverPolicy>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failoverPolicy = mapped
    }

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("ftxhwcddbbckcrtr")
    public fun failoverPolicy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReadWriteEndpointFailoverPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failoverPolicy = mapped
    }

    /**
     * @param value Failover policy of the read-write endpoint for the failover group. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("qiuetpcxpfuomlwl")
    public fun failoverPolicy(`value`: ReadWriteEndpointFailoverPolicy) {
        val toBeMapped = Either.ofRight<String, ReadWriteEndpointFailoverPolicy>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failoverPolicy = mapped
    }

    /**
     * @param value Grace period before failover with data loss is attempted for the read-write endpoint. If failoverPolicy is Automatic then failoverWithDataLossGracePeriodMinutes is required.
     */
    @JvmName("gnhnlfpyjmjhmvux")
    public suspend fun failoverWithDataLossGracePeriodMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failoverWithDataLossGracePeriodMinutes = mapped
    }

    internal fun build(): FailoverGroupReadWriteEndpointArgs = FailoverGroupReadWriteEndpointArgs(
        failoverPolicy = failoverPolicy ?: throw PulumiNullFieldException("failoverPolicy"),
        failoverWithDataLossGracePeriodMinutes = failoverWithDataLossGracePeriodMinutes,
    )
}
